﻿Fluke Calibration                                        All rights reserved.
=============================================================================
INSTRUMENT:            Sub 9640A Check Configuration / Set Parameters
DATE:                  2016-06-08 11:42:23
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 17682 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       120
=============================================================================
#
#  Procedure Author:
#        CAD
#
#  Model(s) Covered:
#        Various (any procedure using the 9640A, 9640A-LPN, 9640A-LPNX,
#                 96040A, or 96270A)
#
#  Compatibility:
#        MET/CAL version 8.3 or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
#  The following 9640A mode strings have different specs based on the 9640A or
#  9640A-LPN installed firmware version.  Firmware versions < 3.0 append
#  " FW<3" to the end of these accuracy file mode strings, while firmware
#  versions >= 3.0 use the base mode strings.  This sub will identify the
#  installed firmware versions, and store the correct mode string in variables
#  for use throughout subsequent procedures.
#
#    Mode: Timebase FW<3
#    Mode: Freq Sine FW<3
#    Mode: Level 50 FW<3
#    Mode: Atten dB 50 FW<3
#    Mode: Atten dB 50 Abs FW<3
#    Mode: Atten dB 75 Abs FW<3
#    Mode: CarFreq AM FW<3
#
#  Example usage of this sub-procedure within the calling procedure:
#        IEEE         [@9640]*IDN?[I$]
#               OR
#        IEEE         [@LPNX]*IDN?[I$]
#        CALL         Sub 9640A Check Configuration and Set Parameters
#
#        IF           @Abort
#        END
#        ENDIF
#
#  Example usage for correct mode strings within a UUT sub-procedure:
#        MATH         AccMode = @AccModeAtten50Abs
#        MATH         RefAcc  = ACCV2(@9640DevName, AccMode, -20, 50E+6)
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Default accuracy file mode strings for specifications not affected by
# firmware change.
  1.001  MATH         @AccModeTimebase   = "Timebase"
  1.002  MATH         @AccModeFreqSine   = "Freq Sine"
  1.003  MATH         @AccModeLevel50    = "Level 50"
  1.004  MATH         @AccModeAtten50    = "Atten dB 50"
  1.005  MATH         @AccModeAtten50Abs = "Atten dB 50 Abs"
  1.006  MATH         @AccModeAtten75Abs = "Atten dB 75 Abs"
  1.007  MATH         @AccModeCarFreqAM  = "CarFreq AM"

# Check for a configured but unaffected RF Reference Source:
#   Fluke 96270A, 96040A, and 9640A-LPNX.
  1.008  MATH         @9640DevName  = INSTR("96270A")

  1.009  IF           EMPTY(@9640DevName)
  1.010  MATH         @9640DevName  = INSTR("96040A")
  1.011  ENDIF

  1.012  IF           EMPTY(@9640DevName)
  1.013  MATH         @9640DevName  = INSTR("LPNX")
  1.014  ENDIF

  1.015  IF           EMPTY(@9640DevName)
# Check for a configured and affected RF Reference Source:
#   Fluke 9640A-LPN or 9640A.
  1.016  MATH         @9640Firmware = FLD(MEM2, 4, ",")
  1.017  MATH         @9640DevName  = INSTR("LPN")

  1.018  IF           EMPTY(@9640DevName)
  1.019  MATH         @9640DevName  = INSTR("9640")
  1.020  ENDIF

# Error if no compatible Fluke RF Reference Source is configured.
  1.021  IF           EMPTY(@9640DevName)
  1.022  DISP         This procedure requires a Fluke 96270A, 96040A, or
  1.022  DISP         9640A Series RF Reference Source, but one has not
  1.022  DISP         been configured.
  1.022  DISP
  1.022  DISP         Terminate this procedure, configure a suitable Fluke
  1.022  DISP         RF Reference Source, then run the procedure again.
  1.023  MATH         @Abort = 1
  1.024  END

  1.025  ELSEIF       @9640Firmware < 3

  1.026  MATH         @AccModeTimebase   = @AccModeTimebase   & " FW<3"
  1.027  MATH         @AccModeFreqSine   = @AccModeFreqSine   & " FW<3"
  1.028  MATH         @AccModeLevel50    = @AccModeLevel50    & " FW<3"
  1.029  MATH         @AccModeAtten50    = @AccModeAtten50    & " FW<3"
  1.030  MATH         @AccModeAtten50Abs = @AccModeAtten50Abs & " FW<3"
  1.031  MATH         @AccModeAtten75Abs = @AccModeAtten75Abs & " FW<3"
  1.032  MATH         @AccModeCarFreqAM  = @AccModeCarFreqAM  & " FW<3"
  1.033  ENDIF

  1.034  ENDIF

  1.035  END
