﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub PSA Compute RF Freq Response Reference Uncertainty
INSTRUMENT:            Sub PSA Compute RF Freq Response Test Uncertainty
DATE:                  2010-10-14
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       101
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Various PSA models
#
#  Compatibility:
#        MET/CAL 7.3.19 or later
#
#  Subprocedures:
#        Sub Compute Mismatch Uncertainty (%)
#
#  Required Files:
#        11667b.acc
#        4419.acc
#
#  Additional Equipment Required:
#        None
#
#   Frequency Response (300 MHz to 3 GHz) is computed using the following:
#    The uncertainties shown in the following ACC statements (stated at k=2)
#    were computed including the following components:
#      - E4419() Instrumentation Accuracy
#      - E4419() Floor Specification
#      - 8485A Power Sensor Cal Factor Uncertainty
#      - 8485A to 11667B Power Splitter Mismatch Uncertainty
#      - 11667B to UUT Mismatch Uncertainty
#    During characterization, since only flatness is relevant, not absolute
#    power, only the 8485A Cal Factor Uncertainty, E4419() Instrumentation
#    Accuracy and Floor Specification, along with the various mismatch
#    uncertainties, are pertinent. The computed uncertainty at the reference
#    is combined (rss) with the uncertainty at each test frequency in order
#    arrive at the total measurement uncertainty.
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Instrumentation (Absolute Power) Accuracy of E4419() in percent.
  1.001  MATH         InstAccy = 0.5
# RSS E4419 Instrument Accuracy and floor specification; the first during
# characterization when measuring the absolute value, the second during
# verification when matching the 'buried' power sensor reading previously
# determined during characterization.
  1.002  MATH         RelAcc = (RSS2(InstAccy, @Floor)) / SQRT(3)

# 8485A Cal Factor Uncertainty (%, taken from Agilent data sheet).
  1.003  MATH         CalFacUnc = 1.4

  1.004  IF           (@CenterFreq > 50E+6)
# RSS Instrumentation Accuracy with 8485A Cal Factor uncertainty.
  1.005  MATH         RelAcc = RSS2(RelAcc, (CalFacUnc / 2))
  1.006  ENDIF

# RSS Instrumentation Accuracy with 8485A Cal Factor uncertainty.
  1.007  MATH         RelAcc = RSS2(RelAcc, (CalFacUnc / 2))
# Retrieve Agilent 11667B (output) SWR at test frequency.
  1.008  MATH         @SourceSWR = ACCV(@DevName, @AccMode, @CenterFreq)
# Compute mismatch uncertainty (Splitter to UUT) during verification.
  1.009  CALL         Sub Compute Mismatch Uncertainty (%)
  1.010  MATH         VerMismatchPct  = @MismatchUncPct
# Save UUT Load SWR for restoration after computing 8485A power sensor
# mismatch uncertainty during characterization.
  1.011  MATH         UUT_SWR = @LoadSWR
# Retrieve (reference) Agilent 8485A (input) SWR at test frequency.
  1.012  MATH         DevName = "Agilent E4419B"
  1.013  MATH         @LoadSWR = ACCV(DevName, "SWR 8485A", @CenterFreq)
# Compute mismatch uncertainty (Splitter to 8485A) during characterization.
  1.014  CALL         Sub Compute Mismatch Uncertainty (%)
  1.015  MATH         CharMismatchPct = @MismatchUncPct
# Flatness uncertainty computed based on mismatch, both during verification
# and characterization, and power meter instrument accuracy (repeatability).
  1.016  MATH         TestUnc = RSS3(VerMismatchPct, CharMismatchPct, RelAcc)

# Store uncertainty (%) of 50 MHz reference set on UUT.
  1.017  IF           PSUBI("Reference")
  1.018  MATH         @RefUnc = TestUnc
  1.019  ELSE
# Combine reference and test uncertainties (%) and convert to dB relative.
  1.020  MATH         M[1] = PCTTODBW_D(RSS2(@RefUnc, TestUnc) * 2)
  1.021  ENDIF

# Restore UUT Load (input) SWR.
  1.022  MATH         @LoadSWR = UUT_SWR
  1.023  END
